@@ -62,7 +62,9 @@ class YamlConfig(ConfigBase):
 
 class ApolloConfig(ConfigBase):
     def __init__(self, app_id: str, server_url: str, cluster: str = "default"):
-        logging.info(f"init config object [ApolloConfig], app_id: [{app_id}], server_url: [{server_url}], cluster: [{cluster}]")
+        logging.info(
+            f"init config object [ApolloConfig], app_id: [{app_id}], server_url: [{server_url}], cluster: [{cluster}]"
+        )
         self.apollo_client = ApolloClient(
             app_id=app_id, config_server_url=server_url, cluster=cluster
         )
